--[[

Interface: 1.4.4.0 1.4.4RC8

Author: GtX | Andy
Date: 30.07.2017
Version: 1.0

History:
V 1.0 @ 30.07.2017 - Release
V 2.0 @ 06.09.2017 - Added as part of IC Scripts.

About: 
Ability to add different sounds to IC controls that use animations. Sound will only work for the player interacting with the IC and does not work on Components set to "isOutside = true".

----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 4 x Modes are available. Different sounds can be assigned to each group if needed.
----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

"singlePlay" 	-  This mode allows you to play a single continues sound for both directions of the animation. Sound is only played while animation is active and plays in a loop form.

"dualOC"  		-  This mode is designed for use with door type animations. <openSound /> is played when animation is started and <closedSound /> is played when animation returns to the start.

"dualPlay" 		-  This mode allows you to play a different continues sounds for both directions of the animation.
				   <openingSound /> is played when animation is started and <closingSound /> is played when animation is returning.

"triPlay"   	-  This mode is designed for use with hydrulic door type animations.
				   <openingSound /> is played when animation is started, <closingSound /> is played when animation is returning and <finishSound /> is played when animation returns to the start.

----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
HOW TO USE - "vehicle.xml" - Information:
----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

windowId			=		This is the "Window" you wish to assign the sounds too. The ID is the listed order of the components starting at the top.

soundMode			=		This is the type of mode you want to use as listed above.

singleSound			=		This can only be used with "singlePlay" soundMode

openSound			=		This can only be used with "dualOC" soundMode

closedSound			=		This can only be used with "dualOC" soundMode

openingSound		=		This can only be used with "dualPlay" and "triPlay" soundMode

closingSound		=		This can only be used with "dualPlay" and "triPlay" soundMode

finishSound			=		This can only be used with "triPlay" soundMode

----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
Example for xml.
----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

<interactiveComponents>

	<windowSounds windowId="1" soundMode="singlePlay">
		<singleSound file="sounds/powerWindow.wav" pitchOffset="1" indoorVolumeFactor="1.0" indoorLowpassGain="1.0" outdoorVolumeFactor="0.5" outdoorLowpassGain="0.3"/>
	</windowSounds>

	<windowSounds windowId="2" soundMode="dualOC">
		<openSound file="sounds/doorOpening.wav" pitchOffset="1" indoorVolumeFactor="1.0" indoorLowpassGain="1.0" outdoorVolumeFactor="0.5" outdoorLowpassGain="0.3"/>
		<closedSound file="sounds/doorClosing.wav" pitchOffset="1" indoorVolumeFactor="1.0" indoorLowpassGain="1.0" outdoorVolumeFactor="0.5" outdoorLowpassGain="0.3"/>
	</windowSounds>
	
	<windowSounds windowId="5" soundMode="dualPlay">
		<openingSound  file="Sound/tuer_auf.wav" pitchOffset="1" indoorVolumeFactor="1.0" indoorLowpassGain="1.0" outdoorVolumeFactor="0.5" outdoorLowpassGain="0.3"/>
		<closingSound file="Sound/tuer_zu.wav" pitchOffset="1" indoorVolumeFactor="1.0" indoorLowpassGain="1.0" outdoorVolumeFactor="0.5" outdoorLowpassGain="0.3"/>
	</windowSounds>	
	
	<windowSounds windowId="3" soundMode="triPlay">
		<openingSound  file="Sound/doorOpen.wav" pitchOffset="1" indoorVolumeFactor="1.0" indoorLowpassGain="1.0" outdoorVolumeFactor="0.5" outdoorLowpassGain="0.3"/>
		<closingSound file="Sound/tuer_zu.wav" pitchOffset="1" indoorVolumeFactor="1.0" indoorLowpassGain="1.0" outdoorVolumeFactor="0.5" outdoorLowpassGain="0.3"/>
		<finishSound file="Sound/tuer_zu2.wav" pitchOffset="1" indoorVolumeFactor="1.0" indoorLowpassGain="1.0" outdoorVolumeFactor="0.5" outdoorLowpassGain="0.3"/>
	</windowSounds>
	
</interactiveComponents>

----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
END:
----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

]]

function InteractiveControl:buttonSoundUpdate(dt) -- need revision
	for i=1, table.getn(self.icSounds) do
		local object = self.LIC.interactiveObjects[self.icSounds[i].windowId];
		
		if object.animation ~= nil then
			if self.icSounds[i].singleSound ~= nil then
				if self:getIsAnimationPlaying(object.animation) and self:getIsActiveForSound() and self.icSounds[i].soundType == "singlePlay" then
					SoundUtil.playSample(self.icSounds[i].singleSound, 0, 0, nil);
				else
					SoundUtil.stopSample(self.icSounds[i].singleSound)
				end;
			end;
		end;
			
			
		if self.icSounds[i].openSound ~= nil and self.icSounds[i].closedSound ~= nil then
			if self:getIsAnimationPlaying(object.animation) and self:getIsActiveForSound() and self.icSounds[i].soundType == "dualOC" then
				if self.animations[object.animation].currentSpeed > 0 and self.animations[object.animation].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.icSounds[i].openSound, 1.5*dt) then
						SoundUtil.playSample(self.icSounds[i].openSound, 1, 0, nil);
					end;
						SoundUtil.stopSample(self.icSounds[i].closedSound)
				elseif self.animations[object.animation].currentSpeed < 0 and self.animations[object.animation].currentTime < 100 then
					if not SoundUtil.isSamplePlaying(self.icSounds[i].closedSound, 1.5*dt) then
						SoundUtil.playSample(self.icSounds[i].closedSound, 1, 0, nil);
					end;
					SoundUtil.stopSample(self.icSounds[i].openSound)
				end;
			end;
		end;
		
		
		if self.icSounds[i].openingSound ~= nil and self.icSounds[i].closingSound ~= nil then
			if self:getIsAnimationPlaying(object.animation) and self:getIsActiveForSound() and self.icSounds[i].soundType == "dualPlay" then
				if self.animations[object.animation].currentSpeed == 1 then
					if not SoundUtil.isSamplePlaying(self.icSounds[i].openingSound, 1.5*dt) then
						SoundUtil.playSample(self.icSounds[i].openingSound, 0, 0, nil);
					end
					SoundUtil.stopSample(self.icSounds[i].closingSound)
				elseif self.animations[object.animation].currentSpeed == -1 then
					if not SoundUtil.isSamplePlaying(self.icSounds[i].closingSound, 1.5*dt) then
						SoundUtil.playSample(self.icSounds[i].closingSound, 0, 0, nil);
					end
					SoundUtil.stopSample(self.icSounds[i].openingSound)
				end;
			else
				SoundUtil.stopSample(self.icSounds[i].openingSound)
				SoundUtil.stopSample(self.icSounds[i].closingSound)
			end;
		end;
		
		if self.icSounds[i].openingSound ~= nil and self.icSounds[i].closingSound ~= nil and self.icSounds[i].finishSound ~= nil then
			if self:getIsAnimationPlaying(object.animation) and self:getIsActiveForSound() and self.icSounds[i].soundType == "triPlay" then
				if self.animations[object.animation].currentSpeed == 1 and self.animations[object.animation].currentTime < 50 then
					if not SoundUtil.isSamplePlaying(self.icSounds[i].openingSound, 1.5*dt) then
						SoundUtil.playSample(self.icSounds[i].openingSound, 1, 0, nil);
					end;
					SoundUtil.stopSample(self.icSounds[i].closingSound)					
				elseif self.animations[object.animation].currentSpeed == -1 and self.animations[object.animation].currentTime > 50 then
					if not SoundUtil.isSamplePlaying(self.icSounds[i].closingSound, 1.5*dt) then
						SoundUtil.playSample(self.icSounds[i].closingSound, 1, 0, nil);
					end;
					SoundUtil.stopSample(self.icSounds[i].openingSound)
				end
				
				if self.animations[object.animation].currentSpeed < 0 and self.animations[object.animation].currentTime < 100 then
					if not SoundUtil.isSamplePlaying(self.icSounds[i].finishSound, 1.5*dt) then
						SoundUtil.playSample(self.icSounds[i].finishSound, 1, 0, nil);
						SoundUtil.stopSample(self.icSounds[i].closingSound)
					end;
				end;
			end;
		end;
			
	end;
end;

function InteractiveControl:windowSoundDelete(self)
	for i=1, table.getn(self.LIC.sounds) do
		if self.isClient then
			SoundUtil.deleteSample(self.LIC.sounds[i].openSound);
			SoundUtil.deleteSample(self.LIC.sounds[i].closedSound);
			SoundUtil.deleteSample(self.LIC.sounds[i].singleSound);
			SoundUtil.deleteSample(self.LIC.sounds[i].finishSound);
			SoundUtil.deleteSample(self.LIC.sounds[i].openingSound);
			SoundUtil.deleteSample(self.LIC.sounds[i].closingSound);
		end;
	end;
end;

function InteractiveControl:windowSoundOnLeave(self)
	for i=1, table.getn(self.icSounds) do
		if self.icSounds[i].openSound ~= nil then  
			if SoundUtil.isSamplePlaying(self.icSounds[i].openSound) then
				SoundUtil.stopSample(self.icSounds[i].openSound)
			end;	
		end;
		if self.icSounds[i].closedSound ~= nil then
			if SoundUtil.isSamplePlaying(self.icSounds[i].closedSound) then
				SoundUtil.stopSample(self.icSounds[i].closedSound)
			end;
		end;
		if self.icSounds[i].singleSound ~= nil then
			if SoundUtil.isSamplePlaying(self.icSounds[i].singleSound) then
				SoundUtil.stopSample(self.icSounds[i].singleSound)
			end;
		end;
		if self.icSounds[i].closingSound ~= nil then
			if SoundUtil.isSamplePlaying(self.icSounds[i].closingSound) then
				SoundUtil.stopSample(self.icSounds[i].closingSound)
			end;
		end;
		if self.icSounds[i].openingSound ~= nil then
			if SoundUtil.isSamplePlaying(self.icSounds[i].openingSound) then
				SoundUtil.stopSample(self.icSounds[i].openingSound)
			end;
		end;
		if self.icSounds[i].finishSound ~= nil then
			if SoundUtil.isSamplePlaying(self.icSounds[i].finishSound) then
				SoundUtil.stopSample(self.icSounds[i].finishSound)
			end;
		end;
	end;
end;